Class: Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb

Overview

The mapping for the Job.edit_list atoms with audio EditAtom.inputs.

Defined Under Namespace

Classes: AudioChannel

Instance Attribute Summary collapse

Instance Attribute Details

#channels::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel>

Returns List of Channels for this audio stream. for in-depth explanation.

Returns:



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 781

class AudioAtom
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The audio channel.
  # @!attribute [rw] inputs
  #   @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel::AudioChannelInput>]
  #     List of `Job.inputs` for this audio channel.
  class AudioChannel
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Identifies which input file, track, and channel should be used.
    # @!attribute [rw] key
    #   @return [::String]
    #     Required. The `Input.key` that identifies the input file.
    # @!attribute [rw] track
    #   @return [::Integer]
    #     Required. The zero-based index of the track in the input file.
    # @!attribute [rw] channel
    #   @return [::Integer]
    #     Required. The zero-based index of the channel in the input file.
    # @!attribute [rw] gain_db
    #   @return [::Float]
    #     Audio volume control in dB. Negative values decrease volume,
    #     positive values increase. The default is 0.
    class AudioChannelInput
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#key::String

Returns Required. The EditAtom.key that references the atom with audio inputs in the Job.edit_list.

Returns:

  • (::String)

    Required. The EditAtom.key that references the atom with audio inputs in the Job.edit_list.



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 781

class AudioAtom
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The audio channel.
  # @!attribute [rw] inputs
  #   @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel::AudioChannelInput>]
  #     List of `Job.inputs` for this audio channel.
  class AudioChannel
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Identifies which input file, track, and channel should be used.
    # @!attribute [rw] key
    #   @return [::String]
    #     Required. The `Input.key` that identifies the input file.
    # @!attribute [rw] track
    #   @return [::Integer]
    #     Required. The zero-based index of the track in the input file.
    # @!attribute [rw] channel
    #   @return [::Integer]
    #     Required. The zero-based index of the channel in the input file.
    # @!attribute [rw] gain_db
    #   @return [::Float]
    #     Audio volume control in dB. Negative values decrease volume,
    #     positive values increase. The default is 0.
    class AudioChannelInput
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end