Class: Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb
Overview
The audio channel.
Defined Under Namespace
Classes: AudioChannelInput
Instance Attribute Summary collapse
-
#inputs ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel::AudioChannelInput>
List of
Job.inputsfor this audio channel.
Instance Attribute Details
#inputs ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel::AudioChannelInput>
Returns List of Job.inputs for this audio channel.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 789 class AudioChannel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Identifies which input file, track, and channel should be used. # @!attribute [rw] key # @return [::String] # Required. The `Input.key` that identifies the input file. # @!attribute [rw] track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] channel # @return [::Integer] # Required. The zero-based index of the channel in the input file. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioChannelInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |