Class: Google::Cloud::Video::Transcoder::V1beta1::Input

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb

Overview

Input asset.

Instance Attribute Summary collapse

Instance Attribute Details

#key::String

Returns A unique key for this input. Must be specified when using advanced mapping and edit lists.

Returns:

  • (::String)

    A unique key for this input. Must be specified when using advanced mapping and edit lists.



188
189
190
191
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 188

class Input
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#preprocessing_config::Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig

Returns Preprocessing configurations.

Returns:



188
189
190
191
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 188

class Input
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#uri::String

Returns URI of the media. It must be stored in Cloud Storage. Example gs://bucket/inputs/file.mp4. If empty the value will be populated from Job.input_uri.

Returns:

  • (::String)

    URI of the media. It must be stored in Cloud Storage. Example gs://bucket/inputs/file.mp4. If empty the value will be populated from Job.input_uri.



188
189
190
191
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 188

class Input
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end