Class: Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig::Audio

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb

Overview

Audio preprocessing configuration.

Instance Attribute Summary collapse

Instance Attribute Details

#high_boost::Boolean

Returns Enable boosting high frequency components. The default is false.

Returns:

  • (::Boolean)

    Enable boosting high frequency components. The default is false.



587
588
589
590
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 587

class Audio
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#low_boost::Boolean

Returns Enable boosting low frequency components. The default is false.

Returns:

  • (::Boolean)

    Enable boosting low frequency components. The default is false.



587
588
589
590
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 587

class Audio
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#lufs::Float

Returns Specify audio loudness normalization in loudness units relative to full scale (LUFS). Enter a value between -24 and 0, where -24 is the Advanced Television Systems Committee (ATSC A/85), -23 is the EU R128 broadcast standard, -19 is the prior standard for online mono audio, -18 is the ReplayGain standard, -16 is the prior standard for stereo audio, -14 is the new online audio standard recommended by Spotify, as well as Amazon Echo, and 0 disables normalization. The default is 0.

Returns:

  • (::Float)

    Specify audio loudness normalization in loudness units relative to full scale (LUFS). Enter a value between -24 and 0, where -24 is the Advanced Television Systems Committee (ATSC A/85), -23 is the EU R128 broadcast standard, -19 is the prior standard for online mono audio, -18 is the ReplayGain standard, -16 is the prior standard for stereo audio, -14 is the new online audio standard recommended by Spotify, as well as Amazon Echo, and 0 disables normalization. The default is 0.



587
588
589
590
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 587

class Audio
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end