Class: Google::Cloud::Video::Transcoder::V1beta1::TextStream
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1beta1::TextStream
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb
Overview
Encoding of a text stream. For example, closed captions or subtitles.
Defined Under Namespace
Classes: TextAtom
Instance Attribute Summary collapse
-
#codec ⇒ ::String
The codec for this text stream.
-
#language_code ⇒ ::String
Required.
-
#mapping ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1beta1::TextStream::TextAtom>
The mapping for the
Job.edit_listatoms with textEditAtom.inputs.
Instance Attribute Details
#codec ⇒ ::String
Returns The codec for this text stream. The default is "webvtt".
Supported text codecs:
- 'srt'
- 'ttml'
- 'cea608'
- 'cea708'
- 'webvtt'.
834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 834 class TextStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the `Job.edit_list` atoms with text `EditAtom.inputs`. # @!attribute [rw] key # @return [::String] # Required. The `EditAtom.key` that references atom with text inputs in the # `Job.edit_list`. # @!attribute [rw] inputs # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::TextStream::TextAtom::TextInput>] # List of `Job.inputs` that should be embedded in this atom. Only one # input is supported. class TextAtom include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Identifies which input file and track should be used. # @!attribute [rw] key # @return [::String] # Required. The `Input.key` that identifies the input file. # @!attribute [rw] track # @return [::Integer] # Required. The zero-based index of the track in the input file. class TextInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#language_code ⇒ ::String
Returns Required. The BCP-47 language code, such as "en-US" or "sr-Latn". For more
information, see
https://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 834 class TextStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the `Job.edit_list` atoms with text `EditAtom.inputs`. # @!attribute [rw] key # @return [::String] # Required. The `EditAtom.key` that references atom with text inputs in the # `Job.edit_list`. # @!attribute [rw] inputs # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::TextStream::TextAtom::TextInput>] # List of `Job.inputs` that should be embedded in this atom. Only one # input is supported. class TextAtom include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Identifies which input file and track should be used. # @!attribute [rw] key # @return [::String] # Required. The `Input.key` that identifies the input file. # @!attribute [rw] track # @return [::Integer] # Required. The zero-based index of the track in the input file. class TextInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#mapping ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1beta1::TextStream::TextAtom>
Returns The mapping for the Job.edit_list atoms with text EditAtom.inputs.
834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 834 class TextStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the `Job.edit_list` atoms with text `EditAtom.inputs`. # @!attribute [rw] key # @return [::String] # Required. The `EditAtom.key` that references atom with text inputs in the # `Job.edit_list`. # @!attribute [rw] inputs # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::TextStream::TextAtom::TextInput>] # List of `Job.inputs` that should be embedded in this atom. Only one # input is supported. class TextAtom include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Identifies which input file and track should be used. # @!attribute [rw] key # @return [::String] # Required. The `Input.key` that identifies the input file. # @!attribute [rw] track # @return [::Integer] # Required. The zero-based index of the track in the input file. class TextInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |