Class: Google::Cloud::Video::Transcoder::V1beta1::TextStream::TextAtom::TextInput
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1beta1::TextStream::TextAtom::TextInput
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb
Overview
Identifies which input file and track should be used.
Instance Attribute Summary collapse
-
#key ⇒ ::String
Required.
-
#track ⇒ ::Integer
Required.
Instance Attribute Details
#key ⇒ ::String
Returns Required. The Input.key that identifies the input file.
929 930 931 932 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 929 class TextInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#track ⇒ ::Integer
Returns Required. The zero-based index of the track in the input file.
929 930 931 932 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 929 class TextInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |