Class: Google::Cloud::Video::Transcoder::V1beta1::TranscoderService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1beta1::TranscoderService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb
Overview
Client for the TranscoderService service.
Using the Transcoder API, you can queue asynchronous jobs for transcoding media into various output formats. Output formats may include different streaming standards such as HTTP Live Streaming (HLS) and Dynamic Adaptive Streaming over HTTP (DASH). You can also customize jobs using advanced features such as Digital Rights Management (DRM), audio equalization, content concatenation, and digital ad-stitch ready content generation.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the TranscoderService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the TranscoderService Client instance.
-
#create_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Job
Creates a job in the specified region.
-
#create_job_template(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::JobTemplate
Creates a job template in the specified region.
-
#delete_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a job.
-
#delete_job_template(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a job template.
-
#get_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Job
Returns the job data.
-
#get_job_template(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::JobTemplate
Returns the job template data.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new TranscoderService client object.
-
#list_job_templates(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1beta1::JobTemplate>
Lists job templates in the specified region.
-
#list_jobs(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1beta1::Job>
Lists jobs in the specified region.
Methods included from Paths
#job_path, #job_template_path, #location_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new TranscoderService client object.
Examples
To create a new TranscoderService client with the default configuration:
client = ::Google::Cloud::Video::Transcoder::V1beta1::TranscoderService::Client.new
To create a new TranscoderService client with a custom configuration:
client = ::Google::Cloud::Video::Transcoder::V1beta1::TranscoderService::Client.new do |config|
config.timeout = 10.0
end
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb', line 141 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/video/transcoder/v1beta1/services_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the scope and endpoint are unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.scope == Client.configure.scope && @config.endpoint == Client.configure.endpoint && !@config.endpoint.split(".").first.include?("-") credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @transcoder_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Video::Transcoder::V1beta1::TranscoderService::Stub, credentials: credentials, endpoint: @config.endpoint, channel_args: @config.channel_args, interceptors: @config.interceptors ) end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the TranscoderService Client class.
See Configuration for a description of the configuration fields.
Example
To modify the configuration for all TranscoderService clients:
::Google::Cloud::Video::Transcoder::V1beta1::TranscoderService::Client.configure do |config|
config.timeout = 10.0
end
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb', line 63 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Video", "Transcoder", "V1beta1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 60.0 default_config.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.create_job.timeout = 60.0 default_config.rpcs.list_jobs.timeout = 60.0 default_config.rpcs.get_job.timeout = 60.0 default_config.rpcs.delete_job.timeout = 60.0 default_config.rpcs.create_job_template.timeout = 60.0 default_config.rpcs.list_job_templates.timeout = 60.0 default_config.rpcs.get_job_template.timeout = 60.0 default_config.rpcs.delete_job_template.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the TranscoderService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
116 117 118 119 |
# File 'lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb', line 116 def configure yield @config if block_given? @config end |
#create_job(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Job #create_job(parent: nil, job: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Job
Creates a job in the specified region.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb', line 212 def create_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1beta1::CreateJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_job..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Video::Transcoder::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_job.timeout, metadata: , retry_policy: @config.rpcs.create_job.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @transcoder_service_stub.call_rpc :create_job, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#create_job_template(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::JobTemplate #create_job_template(parent: nil, job_template: nil, job_template_id: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::JobTemplate
Creates a job template in the specified region.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb', line 493 def create_job_template request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1beta1::CreateJobTemplateRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_job_template..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Video::Transcoder::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_job_template.timeout, metadata: , retry_policy: @config.rpcs.create_job_template.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @transcoder_service_stub.call_rpc :create_job_template, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_job(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_job(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a job.
418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb', line 418 def delete_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1beta1::DeleteJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_job..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Video::Transcoder::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_job.timeout, metadata: , retry_policy: @config.rpcs.delete_job.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @transcoder_service_stub.call_rpc :delete_job, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_job_template(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_job_template(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a job template.
701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 |
# File 'lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb', line 701 def delete_job_template request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1beta1::DeleteJobTemplateRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_job_template..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Video::Transcoder::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_job_template.timeout, metadata: , retry_policy: @config.rpcs.delete_job_template.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @transcoder_service_stub.call_rpc :delete_job_template, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_job(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Job #get_job(name: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Job
Returns the job data.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb', line 351 def get_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1beta1::GetJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_job..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Video::Transcoder::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_job.timeout, metadata: , retry_policy: @config.rpcs.get_job.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @transcoder_service_stub.call_rpc :get_job, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_job_template(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::JobTemplate #get_job_template(name: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::JobTemplate
Returns the job template data.
634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 |
# File 'lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb', line 634 def get_job_template request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1beta1::GetJobTemplateRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_job_template..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Video::Transcoder::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_job_template.timeout, metadata: , retry_policy: @config.rpcs.get_job_template.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @transcoder_service_stub.call_rpc :get_job_template, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_job_templates(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1beta1::JobTemplate> #list_job_templates(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1beta1::JobTemplate>
Lists job templates in the specified region.
565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 |
# File 'lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb', line 565 def list_job_templates request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1beta1::ListJobTemplatesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_job_templates..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Video::Transcoder::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_job_templates.timeout, metadata: , retry_policy: @config.rpcs.list_job_templates.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @transcoder_service_stub.call_rpc :list_job_templates, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @transcoder_service_stub, :list_job_templates, request, response, operation, yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_jobs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1beta1::Job> #list_jobs(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1beta1::Job>
Lists jobs in the specified region.
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/google/cloud/video/transcoder/v1beta1/transcoder_service/client.rb', line 283 def list_jobs request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1beta1::ListJobsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_jobs..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Video::Transcoder::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_jobs.timeout, metadata: , retry_policy: @config.rpcs.list_jobs.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @transcoder_service_stub.call_rpc :list_jobs, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @transcoder_service_stub, :list_jobs, request, response, operation, yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |