Class: Google::Cloud::Video::Transcoder::V1beta1::VideoStream

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb

Overview

Video stream resource.

Instance Attribute Summary collapse

Instance Attribute Details

#allow_open_gop::Boolean

Returns Specifies whether an open Group of Pictures (GOP) structure should be allowed or not. The default is false.

Returns:

  • (::Boolean)

    Specifies whether an open Group of Pictures (GOP) structure should be allowed or not. The default is false.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#aq_strength::Float

Returns Specify the intensity of the adaptive quantizer (AQ). Must be between 0 and 1, where 0 disables the quantizer and 1 maximizes the quantizer. A higher value equals a lower bitrate but smoother image. The default is 0.

Returns:

  • (::Float)

    Specify the intensity of the adaptive quantizer (AQ). Must be between 0 and 1, where 0 disables the quantizer and 1 maximizes the quantizer. A higher value equals a lower bitrate but smoother image. The default is 0.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#b_frame_count::Integer

Returns The number of consecutive B-frames. Must be greater than or equal to zero. Must be less than VideoStream.gop_frame_count if set. The default is 0.

Returns:

  • (::Integer)

    The number of consecutive B-frames. Must be greater than or equal to zero. Must be less than VideoStream.gop_frame_count if set. The default is 0.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#b_pyramid::Boolean

Returns Allow B-pyramid for reference frame selection. This may not be supported on all decoders. The default is false.

Returns:

  • (::Boolean)

    Allow B-pyramid for reference frame selection. This may not be supported on all decoders. The default is false.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#bitrate_bps::Integer

Returns Required. The video bitrate in bits per second. Must be between 1 and 1,000,000,000.

Returns:

  • (::Integer)

    Required. The video bitrate in bits per second. Must be between 1 and 1,000,000,000.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#codec::String

Returns Codec type. The default is "h264".

Supported codecs:

  • 'h264'
  • 'h265'
  • 'vp9'.

Returns:

  • (::String)

    Codec type. The default is "h264".

    Supported codecs:

    • 'h264'
    • 'h265'
    • 'vp9'


726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#crf_level::Integer

Returns Target CRF level. Must be between 10 and 36, where 10 is the highest quality and 36 is the most efficient compression. The default is 21.

Returns:

  • (::Integer)

    Target CRF level. Must be between 10 and 36, where 10 is the highest quality and 36 is the most efficient compression. The default is 21.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_two_pass::Boolean

Returns Use two-pass encoding strategy to achieve better video quality. VideoStream.rate_control_mode must be "vbr". The default is false.

Returns:

  • (::Boolean)

    Use two-pass encoding strategy to achieve better video quality. VideoStream.rate_control_mode must be "vbr". The default is false.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#entropy_coder::String

Returns The entropy coder to use. The default is "cabac".

Supported entropy coders:

  • 'cavlc'
  • 'cabac'.

Returns:

  • (::String)

    The entropy coder to use. The default is "cabac".

    Supported entropy coders:

    • 'cavlc'
    • 'cabac'


726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#frame_rate::Float

Returns Required. The target video frame rate in frames per second (FPS). Must be less than or equal to 120. Will default to the input frame rate if larger than the input frame rate. The API will generate an output FPS that is divisible by the input FPS, and smaller or equal to the target FPS.

The following table shows the computed video FPS given the target FPS (in parenthesis) and input FPS (in the first column):

|        | (30)   | (60)   | (25) | (50) |
|--------|--------|--------|------|------|
| 240    | Fail   | Fail   | Fail | Fail |
| 120    | 30     | 60     | 20   | 30   |
| 100    | 25     | 50     | 20   | 30   |
| 50     | 25     | 50     | 20   | 30   |
| 60     | 30     | 60     | 20   | 30   |
| 59.94  | 29.97  | 59.94  | 20   | 30   |
| 48     | 24     | 48     | 20   | 30   |
| 30     | 30     | 30     | 20   | 30   |
| 25     | 25     | 25     | 20   | 30   |
| 24     | 24     | 24     | 20   | 30   |
| 23.976 | 23.976 | 23.976 | 20   | 30   |
| 15     | 15     | 15     | 20   | 30   |
| 12     | 12     | 12     | 20   | 30   |
| 10     | 10     | 10     | 20   | 30   |
```.

Returns:

  • (::Float)

    Required. The target video frame rate in frames per second (FPS). Must be less than or equal to 120. Will default to the input frame rate if larger than the input frame rate. The API will generate an output FPS that is divisible by the input FPS, and smaller or equal to the target FPS.

    The following table shows the computed video FPS given the target FPS (in parenthesis) and input FPS (in the first column):

    |        | (30)   | (60)   | (25) | (50) |
    |--------|--------|--------|------|------|
    | 240    | Fail   | Fail   | Fail | Fail |
    | 120    | 30     | 60     | 20   | 30   |
    | 100    | 25     | 50     | 20   | 30   |
    | 50     | 25     | 50     | 20   | 30   |
    | 60     | 30     | 60     | 20   | 30   |
    | 59.94  | 29.97  | 59.94  | 20   | 30   |
    | 48     | 24     | 48     | 20   | 30   |
    | 30     | 30     | 30     | 20   | 30   |
    | 25     | 25     | 25     | 20   | 30   |
    | 24     | 24     | 24     | 20   | 30   |
    | 23.976 | 23.976 | 23.976 | 20   | 30   |
    | 15     | 15     | 15     | 20   | 30   |
    | 12     | 12     | 12     | 20   | 30   |
    | 10     | 10     | 10     | 20   | 30   |
    


726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gop_duration::Google::Protobuf::Duration

Returns Select the GOP size based on the specified duration. The default is "3s".

Returns:



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gop_frame_count::Integer

Returns Select the GOP size based on the specified frame count. Must be greater than zero.

Returns:

  • (::Integer)

    Select the GOP size based on the specified frame count. Must be greater than zero.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#height_pixels::Integer

Returns The height of the video in pixels. Must be an even integer. When not specified, the height is adjusted to match the specified width and input aspect ratio. If both are omitted, the input height is used.

Returns:

  • (::Integer)

    The height of the video in pixels. Must be an even integer. When not specified, the height is adjusted to match the specified width and input aspect ratio. If both are omitted, the input height is used.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pixel_format::String

Returns Pixel format to use. The default is "yuv420p".

Supported pixel formats:

  • 'yuv420p' pixel format.
  • 'yuv422p' pixel format.
  • 'yuv444p' pixel format.
  • 'yuv420p10' 10-bit HDR pixel format.
  • 'yuv422p10' 10-bit HDR pixel format.
  • 'yuv444p10' 10-bit HDR pixel format.
  • 'yuv420p12' 12-bit HDR pixel format.
  • 'yuv422p12' 12-bit HDR pixel format.
  • 'yuv444p12' 12-bit HDR pixel format.

Returns:

  • (::String)

    Pixel format to use. The default is "yuv420p".

    Supported pixel formats:

    • 'yuv420p' pixel format.
    • 'yuv422p' pixel format.
    • 'yuv444p' pixel format.
    • 'yuv420p10' 10-bit HDR pixel format.
    • 'yuv422p10' 10-bit HDR pixel format.
    • 'yuv444p10' 10-bit HDR pixel format.
    • 'yuv420p12' 12-bit HDR pixel format.
    • 'yuv422p12' 12-bit HDR pixel format.
    • 'yuv444p12' 12-bit HDR pixel format.


726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#preset::String

Returns Enforce specified codec preset. The default is "veryfast".

Returns:

  • (::String)

    Enforce specified codec preset. The default is "veryfast".



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#profile::String

Returns Enforce specified codec profile. The default is "high".

Supported codec profiles:

  • 'baseline'
  • 'main'
  • 'high'.

Returns:

  • (::String)

    Enforce specified codec profile. The default is "high".

    Supported codec profiles:

    • 'baseline'
    • 'main'
    • 'high'


726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rate_control_mode::String

Returns Specify the rate_control_mode. The default is "vbr".

Supported rate control modes:

  • 'vbr' - variable bitrate
  • 'crf' - constant rate factor.

Returns:

  • (::String)

    Specify the rate_control_mode. The default is "vbr".

    Supported rate control modes:

    • 'vbr' - variable bitrate
    • 'crf' - constant rate factor


726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tune::String

Returns Enforce specified codec tune.

Returns:

  • (::String)

    Enforce specified codec tune.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vbv_fullness_bits::Integer

Returns Initial fullness of the Video Buffering Verifier (VBV) buffer in bits. Must be greater than zero. The default is equal to 90% of VideoStream.vbv_size_bits.

Returns:

  • (::Integer)

    Initial fullness of the Video Buffering Verifier (VBV) buffer in bits. Must be greater than zero. The default is equal to 90% of VideoStream.vbv_size_bits.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vbv_size_bits::Integer

Returns Size of the Video Buffering Verifier (VBV) buffer in bits. Must be greater than zero. The default is equal to VideoStream.bitrate_bps.

Returns:

  • (::Integer)

    Size of the Video Buffering Verifier (VBV) buffer in bits. Must be greater than zero. The default is equal to VideoStream.bitrate_bps.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#width_pixels::Integer

Returns The width of the video in pixels. Must be an even integer. When not specified, the width is adjusted to match the specified height and input aspect ratio. If both are omitted, the input width is used.

Returns:

  • (::Integer)

    The width of the video in pixels. Must be an even integer. When not specified, the width is adjusted to match the specified height and input aspect ratio. If both are omitted, the input width is used.



726
727
728
729
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 726

class VideoStream
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end