Class: Google::Cloud::Video::Transcoder::V1beta1::AudioStream
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1beta1::AudioStream
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb
Overview
Audio stream resource.
Defined Under Namespace
Classes: AudioAtom
Instance Attribute Summary collapse
-
#bitrate_bps ⇒ ::Integer
Required.
-
#channel_count ⇒ ::Integer
Number of audio channels.
-
#channel_layout ⇒ ::Array<::String>
A list of channel names specifying layout of the audio channels.
-
#codec ⇒ ::String
The codec for this audio stream.
-
#mapping ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom>
The mapping for the
Job.edit_listatoms with audioEditAtom.inputs. -
#sample_rate_hertz ⇒ ::Integer
The audio sample rate in Hertz.
Instance Attribute Details
#bitrate_bps ⇒ ::Integer
Returns Required. Audio bitrate in bits per second. Must be between 1 and 10,000,000.
768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 768 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the `Job.edit_list` atoms with audio `EditAtom.inputs`. # @!attribute [rw] key # @return [::String] # Required. The `EditAtom.key` that references the atom with audio inputs in the # `Job.edit_list`. # @!attribute [rw] channels # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel>] # List of `Channel`s for this audio stream. # for in-depth explanation. class AudioAtom include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The audio channel. # @!attribute [rw] inputs # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel::AudioChannelInput>] # List of `Job.inputs` for this audio channel. class AudioChannel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Identifies which input file, track, and channel should be used. # @!attribute [rw] key # @return [::String] # Required. The `Input.key` that identifies the input file. # @!attribute [rw] track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] channel # @return [::Integer] # Required. The zero-based index of the channel in the input file. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioChannelInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#channel_count ⇒ ::Integer
Returns Number of audio channels. Must be between 1 and 6. The default is 2.
768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 768 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the `Job.edit_list` atoms with audio `EditAtom.inputs`. # @!attribute [rw] key # @return [::String] # Required. The `EditAtom.key` that references the atom with audio inputs in the # `Job.edit_list`. # @!attribute [rw] channels # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel>] # List of `Channel`s for this audio stream. # for in-depth explanation. class AudioAtom include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The audio channel. # @!attribute [rw] inputs # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel::AudioChannelInput>] # List of `Job.inputs` for this audio channel. class AudioChannel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Identifies which input file, track, and channel should be used. # @!attribute [rw] key # @return [::String] # Required. The `Input.key` that identifies the input file. # @!attribute [rw] track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] channel # @return [::Integer] # Required. The zero-based index of the channel in the input file. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioChannelInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#channel_layout ⇒ ::Array<::String>
Returns A list of channel names specifying layout of the audio channels.
This only affects the metadata embedded in the container headers, if
supported by the specified format. The default is ["fl", "fr"].
Supported channel names:
- 'fl' - Front left channel
- 'fr' - Front right channel
- 'sl' - Side left channel
- 'sr' - Side right channel
- 'fc' - Front center channel
- 'lfe' - Low frequency.
768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 768 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the `Job.edit_list` atoms with audio `EditAtom.inputs`. # @!attribute [rw] key # @return [::String] # Required. The `EditAtom.key` that references the atom with audio inputs in the # `Job.edit_list`. # @!attribute [rw] channels # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel>] # List of `Channel`s for this audio stream. # for in-depth explanation. class AudioAtom include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The audio channel. # @!attribute [rw] inputs # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel::AudioChannelInput>] # List of `Job.inputs` for this audio channel. class AudioChannel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Identifies which input file, track, and channel should be used. # @!attribute [rw] key # @return [::String] # Required. The `Input.key` that identifies the input file. # @!attribute [rw] track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] channel # @return [::Integer] # Required. The zero-based index of the channel in the input file. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioChannelInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#codec ⇒ ::String
Returns The codec for this audio stream. The default is "aac".
Supported audio codecs:
- 'aac'
- 'aac-he'
- 'aac-he-v2'
- 'mp3'
- 'ac3'
- 'eac3'.
768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 768 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the `Job.edit_list` atoms with audio `EditAtom.inputs`. # @!attribute [rw] key # @return [::String] # Required. The `EditAtom.key` that references the atom with audio inputs in the # `Job.edit_list`. # @!attribute [rw] channels # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel>] # List of `Channel`s for this audio stream. # for in-depth explanation. class AudioAtom include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The audio channel. # @!attribute [rw] inputs # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel::AudioChannelInput>] # List of `Job.inputs` for this audio channel. class AudioChannel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Identifies which input file, track, and channel should be used. # @!attribute [rw] key # @return [::String] # Required. The `Input.key` that identifies the input file. # @!attribute [rw] track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] channel # @return [::Integer] # Required. The zero-based index of the channel in the input file. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioChannelInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#mapping ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom>
Returns The mapping for the Job.edit_list atoms with audio EditAtom.inputs.
768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 768 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the `Job.edit_list` atoms with audio `EditAtom.inputs`. # @!attribute [rw] key # @return [::String] # Required. The `EditAtom.key` that references the atom with audio inputs in the # `Job.edit_list`. # @!attribute [rw] channels # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel>] # List of `Channel`s for this audio stream. # for in-depth explanation. class AudioAtom include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The audio channel. # @!attribute [rw] inputs # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel::AudioChannelInput>] # List of `Job.inputs` for this audio channel. class AudioChannel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Identifies which input file, track, and channel should be used. # @!attribute [rw] key # @return [::String] # Required. The `Input.key` that identifies the input file. # @!attribute [rw] track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] channel # @return [::Integer] # Required. The zero-based index of the channel in the input file. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioChannelInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#sample_rate_hertz ⇒ ::Integer
Returns The audio sample rate in Hertz. The default is 48000 Hertz.
768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 768 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the `Job.edit_list` atoms with audio `EditAtom.inputs`. # @!attribute [rw] key # @return [::String] # Required. The `EditAtom.key` that references the atom with audio inputs in the # `Job.edit_list`. # @!attribute [rw] channels # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel>] # List of `Channel`s for this audio stream. # for in-depth explanation. class AudioAtom include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The audio channel. # @!attribute [rw] inputs # @return [::Array<::Google::Cloud::Video::Transcoder::V1beta1::AudioStream::AudioAtom::AudioChannel::AudioChannelInput>] # List of `Job.inputs` for this audio channel. class AudioChannel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Identifies which input file, track, and channel should be used. # @!attribute [rw] key # @return [::String] # Required. The `Input.key` that identifies the input file. # @!attribute [rw] track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] channel # @return [::Integer] # Required. The zero-based index of the channel in the input file. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioChannelInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |