Class: Google::Cloud::Video::Transcoder::V1beta1::Encryption
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1beta1::Encryption
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb
Overview
Encryption settings.
Defined Under Namespace
Classes: Aes128Encryption, MpegCommonEncryption, SampleAesEncryption
Instance Attribute Summary collapse
-
#aes_128 ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Encryption::Aes128Encryption
Configuration for AES-128 encryption.
-
#iv ⇒ ::String
Required.
-
#key ⇒ ::String
Required.
-
#mpeg_cenc ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Encryption::MpegCommonEncryption
Configuration for MPEG Common Encryption (MPEG-CENC).
-
#sample_aes ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Encryption::SampleAesEncryption
Configuration for SAMPLE-AES encryption.
Instance Attribute Details
#aes_128 ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Encryption::Aes128Encryption
Returns Configuration for AES-128 encryption.
894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 894 class Encryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for AES-128 encryption. # @!attribute [rw] key_uri # @return [::String] # Required. URI of the key delivery service. This URI is inserted into the M3U8 # header. class Aes128Encryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for SAMPLE-AES encryption. # @!attribute [rw] key_uri # @return [::String] # Required. URI of the key delivery service. This URI is inserted into the M3U8 # header. class SampleAesEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for MPEG Common Encryption (MPEG-CENC). # @!attribute [rw] key_id # @return [::String] # Required. 128 bit Key ID represented as lowercase hexadecimal digits for use with # common encryption. # @!attribute [rw] scheme # @return [::String] # Required. Specify the encryption scheme. # # Supported encryption schemes: # - 'cenc' # - 'cbcs' class MpegCommonEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#iv ⇒ ::String
Returns Required. 128 bit Initialization Vector (IV) represented as lowercase hexadecimal digits.
894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 894 class Encryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for AES-128 encryption. # @!attribute [rw] key_uri # @return [::String] # Required. URI of the key delivery service. This URI is inserted into the M3U8 # header. class Aes128Encryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for SAMPLE-AES encryption. # @!attribute [rw] key_uri # @return [::String] # Required. URI of the key delivery service. This URI is inserted into the M3U8 # header. class SampleAesEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for MPEG Common Encryption (MPEG-CENC). # @!attribute [rw] key_id # @return [::String] # Required. 128 bit Key ID represented as lowercase hexadecimal digits for use with # common encryption. # @!attribute [rw] scheme # @return [::String] # Required. Specify the encryption scheme. # # Supported encryption schemes: # - 'cenc' # - 'cbcs' class MpegCommonEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#key ⇒ ::String
Returns Required. 128 bit encryption key represented as lowercase hexadecimal digits.
894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 894 class Encryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for AES-128 encryption. # @!attribute [rw] key_uri # @return [::String] # Required. URI of the key delivery service. This URI is inserted into the M3U8 # header. class Aes128Encryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for SAMPLE-AES encryption. # @!attribute [rw] key_uri # @return [::String] # Required. URI of the key delivery service. This URI is inserted into the M3U8 # header. class SampleAesEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for MPEG Common Encryption (MPEG-CENC). # @!attribute [rw] key_id # @return [::String] # Required. 128 bit Key ID represented as lowercase hexadecimal digits for use with # common encryption. # @!attribute [rw] scheme # @return [::String] # Required. Specify the encryption scheme. # # Supported encryption schemes: # - 'cenc' # - 'cbcs' class MpegCommonEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#mpeg_cenc ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Encryption::MpegCommonEncryption
Returns Configuration for MPEG Common Encryption (MPEG-CENC).
894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 894 class Encryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for AES-128 encryption. # @!attribute [rw] key_uri # @return [::String] # Required. URI of the key delivery service. This URI is inserted into the M3U8 # header. class Aes128Encryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for SAMPLE-AES encryption. # @!attribute [rw] key_uri # @return [::String] # Required. URI of the key delivery service. This URI is inserted into the M3U8 # header. class SampleAesEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for MPEG Common Encryption (MPEG-CENC). # @!attribute [rw] key_id # @return [::String] # Required. 128 bit Key ID represented as lowercase hexadecimal digits for use with # common encryption. # @!attribute [rw] scheme # @return [::String] # Required. Specify the encryption scheme. # # Supported encryption schemes: # - 'cenc' # - 'cbcs' class MpegCommonEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#sample_aes ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::Encryption::SampleAesEncryption
Returns Configuration for SAMPLE-AES encryption.
894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 894 class Encryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for AES-128 encryption. # @!attribute [rw] key_uri # @return [::String] # Required. URI of the key delivery service. This URI is inserted into the M3U8 # header. class Aes128Encryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for SAMPLE-AES encryption. # @!attribute [rw] key_uri # @return [::String] # Required. URI of the key delivery service. This URI is inserted into the M3U8 # header. class SampleAesEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for MPEG Common Encryption (MPEG-CENC). # @!attribute [rw] key_id # @return [::String] # Required. 128 bit Key ID represented as lowercase hexadecimal digits for use with # common encryption. # @!attribute [rw] scheme # @return [::String] # Required. Specify the encryption scheme. # # Supported encryption schemes: # - 'cenc' # - 'cbcs' class MpegCommonEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |