Class: Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb
Overview
Preprocessing configurations.
Defined Under Namespace
Classes: Audio, Color, Deblock, Denoise
Instance Attribute Summary collapse
-
#audio ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig::Audio
Audio preprocessing configuration.
-
#color ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig::Color
Color preprocessing configuration.
-
#deblock ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig::Deblock
Deblock preprocessing configuration.
-
#denoise ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig::Denoise
Denoise preprocessing configuration.
Instance Attribute Details
#audio ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig::Audio
Returns Audio preprocessing configuration.
515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 515 class PreprocessingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Color preprocessing configuration. # @!attribute [rw] saturation # @return [::Float] # Control color saturation of the video. Enter a value between -1 and 1, # where -1 is fully desaturated and 1 is maximum saturation. 0 is no # change. The default is 0. # @!attribute [rw] contrast # @return [::Float] # Control black and white contrast of the video. Enter a value between -1 # and 1, where -1 is minimum contrast and 1 is maximum contrast. 0 is no # change. The default is 0. # @!attribute [rw] brightness # @return [::Float] # Control brightness of the video. Enter a value between -1 and 1, where -1 # is minimum brightness and 1 is maximum brightness. 0 is no change. The # default is 0. class Color include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Denoise preprocessing configuration. # @!attribute [rw] strength # @return [::Float] # Set strength of the denoise. Enter a value between 0 and 1. The higher # the value, the smoother the image. 0 is no denoising. The default is 0. # @!attribute [rw] tune # @return [::String] # Set the denoiser mode. The default is `"standard"`. # # Supported denoiser modes: # - 'standard' # - 'grain' class Denoise include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Deblock preprocessing configuration. # @!attribute [rw] strength # @return [::Float] # Set strength of the deblocker. Enter a value between 0 and 1. The higher # the value, the stronger the block removal. 0 is no deblocking. The # default is 0. # @!attribute [rw] enabled # @return [::Boolean] # Enable deblocker. The default is `false`. class Deblock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Audio preprocessing configuration. # @!attribute [rw] lufs # @return [::Float] # Specify audio loudness normalization in loudness units relative to full # scale (LUFS). Enter a value between -24 and 0, where -24 is the Advanced # Television Systems Committee (ATSC A/85), -23 is the EU R128 broadcast # standard, -19 is the prior standard for online mono audio, -18 is the # ReplayGain standard, -16 is the prior standard for stereo audio, -14 is # the new online audio standard recommended by Spotify, as well as Amazon # Echo, and 0 disables normalization. The default is 0. # @!attribute [rw] high_boost # @return [::Boolean] # Enable boosting high frequency components. The default is `false`. # @!attribute [rw] low_boost # @return [::Boolean] # Enable boosting low frequency components. The default is `false`. class Audio include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#color ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig::Color
Returns Color preprocessing configuration.
515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 515 class PreprocessingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Color preprocessing configuration. # @!attribute [rw] saturation # @return [::Float] # Control color saturation of the video. Enter a value between -1 and 1, # where -1 is fully desaturated and 1 is maximum saturation. 0 is no # change. The default is 0. # @!attribute [rw] contrast # @return [::Float] # Control black and white contrast of the video. Enter a value between -1 # and 1, where -1 is minimum contrast and 1 is maximum contrast. 0 is no # change. The default is 0. # @!attribute [rw] brightness # @return [::Float] # Control brightness of the video. Enter a value between -1 and 1, where -1 # is minimum brightness and 1 is maximum brightness. 0 is no change. The # default is 0. class Color include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Denoise preprocessing configuration. # @!attribute [rw] strength # @return [::Float] # Set strength of the denoise. Enter a value between 0 and 1. The higher # the value, the smoother the image. 0 is no denoising. The default is 0. # @!attribute [rw] tune # @return [::String] # Set the denoiser mode. The default is `"standard"`. # # Supported denoiser modes: # - 'standard' # - 'grain' class Denoise include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Deblock preprocessing configuration. # @!attribute [rw] strength # @return [::Float] # Set strength of the deblocker. Enter a value between 0 and 1. The higher # the value, the stronger the block removal. 0 is no deblocking. The # default is 0. # @!attribute [rw] enabled # @return [::Boolean] # Enable deblocker. The default is `false`. class Deblock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Audio preprocessing configuration. # @!attribute [rw] lufs # @return [::Float] # Specify audio loudness normalization in loudness units relative to full # scale (LUFS). Enter a value between -24 and 0, where -24 is the Advanced # Television Systems Committee (ATSC A/85), -23 is the EU R128 broadcast # standard, -19 is the prior standard for online mono audio, -18 is the # ReplayGain standard, -16 is the prior standard for stereo audio, -14 is # the new online audio standard recommended by Spotify, as well as Amazon # Echo, and 0 disables normalization. The default is 0. # @!attribute [rw] high_boost # @return [::Boolean] # Enable boosting high frequency components. The default is `false`. # @!attribute [rw] low_boost # @return [::Boolean] # Enable boosting low frequency components. The default is `false`. class Audio include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#deblock ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig::Deblock
Returns Deblock preprocessing configuration.
515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 515 class PreprocessingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Color preprocessing configuration. # @!attribute [rw] saturation # @return [::Float] # Control color saturation of the video. Enter a value between -1 and 1, # where -1 is fully desaturated and 1 is maximum saturation. 0 is no # change. The default is 0. # @!attribute [rw] contrast # @return [::Float] # Control black and white contrast of the video. Enter a value between -1 # and 1, where -1 is minimum contrast and 1 is maximum contrast. 0 is no # change. The default is 0. # @!attribute [rw] brightness # @return [::Float] # Control brightness of the video. Enter a value between -1 and 1, where -1 # is minimum brightness and 1 is maximum brightness. 0 is no change. The # default is 0. class Color include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Denoise preprocessing configuration. # @!attribute [rw] strength # @return [::Float] # Set strength of the denoise. Enter a value between 0 and 1. The higher # the value, the smoother the image. 0 is no denoising. The default is 0. # @!attribute [rw] tune # @return [::String] # Set the denoiser mode. The default is `"standard"`. # # Supported denoiser modes: # - 'standard' # - 'grain' class Denoise include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Deblock preprocessing configuration. # @!attribute [rw] strength # @return [::Float] # Set strength of the deblocker. Enter a value between 0 and 1. The higher # the value, the stronger the block removal. 0 is no deblocking. The # default is 0. # @!attribute [rw] enabled # @return [::Boolean] # Enable deblocker. The default is `false`. class Deblock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Audio preprocessing configuration. # @!attribute [rw] lufs # @return [::Float] # Specify audio loudness normalization in loudness units relative to full # scale (LUFS). Enter a value between -24 and 0, where -24 is the Advanced # Television Systems Committee (ATSC A/85), -23 is the EU R128 broadcast # standard, -19 is the prior standard for online mono audio, -18 is the # ReplayGain standard, -16 is the prior standard for stereo audio, -14 is # the new online audio standard recommended by Spotify, as well as Amazon # Echo, and 0 disables normalization. The default is 0. # @!attribute [rw] high_boost # @return [::Boolean] # Enable boosting high frequency components. The default is `false`. # @!attribute [rw] low_boost # @return [::Boolean] # Enable boosting low frequency components. The default is `false`. class Audio include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#denoise ⇒ ::Google::Cloud::Video::Transcoder::V1beta1::PreprocessingConfig::Denoise
Returns Denoise preprocessing configuration.
515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'proto_docs/google/cloud/video/transcoder/v1beta1/resources.rb', line 515 class PreprocessingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Color preprocessing configuration. # @!attribute [rw] saturation # @return [::Float] # Control color saturation of the video. Enter a value between -1 and 1, # where -1 is fully desaturated and 1 is maximum saturation. 0 is no # change. The default is 0. # @!attribute [rw] contrast # @return [::Float] # Control black and white contrast of the video. Enter a value between -1 # and 1, where -1 is minimum contrast and 1 is maximum contrast. 0 is no # change. The default is 0. # @!attribute [rw] brightness # @return [::Float] # Control brightness of the video. Enter a value between -1 and 1, where -1 # is minimum brightness and 1 is maximum brightness. 0 is no change. The # default is 0. class Color include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Denoise preprocessing configuration. # @!attribute [rw] strength # @return [::Float] # Set strength of the denoise. Enter a value between 0 and 1. The higher # the value, the smoother the image. 0 is no denoising. The default is 0. # @!attribute [rw] tune # @return [::String] # Set the denoiser mode. The default is `"standard"`. # # Supported denoiser modes: # - 'standard' # - 'grain' class Denoise include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Deblock preprocessing configuration. # @!attribute [rw] strength # @return [::Float] # Set strength of the deblocker. Enter a value between 0 and 1. The higher # the value, the stronger the block removal. 0 is no deblocking. The # default is 0. # @!attribute [rw] enabled # @return [::Boolean] # Enable deblocker. The default is `false`. class Deblock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Audio preprocessing configuration. # @!attribute [rw] lufs # @return [::Float] # Specify audio loudness normalization in loudness units relative to full # scale (LUFS). Enter a value between -24 and 0, where -24 is the Advanced # Television Systems Committee (ATSC A/85), -23 is the EU R128 broadcast # standard, -19 is the prior standard for online mono audio, -18 is the # ReplayGain standard, -16 is the prior standard for stereo audio, -14 is # the new online audio standard recommended by Spotify, as well as Amazon # Echo, and 0 disables normalization. The default is 0. # @!attribute [rw] high_boost # @return [::Boolean] # Enable boosting high frequency components. The default is `false`. # @!attribute [rw] low_boost # @return [::Boolean] # Enable boosting low frequency components. The default is `false`. class Audio include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |